
  { Setup program for ExtraHelp - Jon Webb, july 7th 1996           }
  { Freeware; please report bugs, bug fixes, comments, enhancements }
  { etc. to j.webb@marketresponse.nl                                }

unit Setupfrm;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls;

type
  TSetupForm = class(TForm)
    Panel1: TPanel;
    Notebook: TNotebook;
    Panel2: TPanel;
    Memo1: TMemo;
    Label1: TLabel;
    BinDirectory: TEdit;
    BrowseBinBtn: TButton;
    NextBtn: TButton;
    FinishBtn: TButton;
    PrevBtn: TButton;
    CancelBtn: TButton;
    Memo2: TMemo;
    OptionsBtn: TButton;
    Memo3: TMemo;
    Memo4: TMemo;
    Label2: TLabel;
    Memo5: TMemo;
    Bevel1: TBevel;
    Bevel2: TBevel;
    procedure BrowseBinBtnClick(Sender: TObject);
    procedure CancelBtnClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure NextBtnClick(Sender: TObject);
    procedure OptionsBtnClick(Sender: TObject);
    procedure PrevBtnClick(Sender: TObject);
    procedure FinishBtnClick(Sender: TObject);
    procedure BinDirectoryChange(Sender: TObject);
  private    { Private declarations }
    vcs: string;
    procedure CheckButtons;
  public     { Public declarations }
  end;

var
  SetupForm: TSetupForm;

implementation

{$R *.DFM}

uses lzExpand, options, selDir;

function CopyFile(FromFileName, ToFileName: string) : Boolean; {From Lloyds help file}
var
  FromFile, ToFile: File;
begin
  AssignFile(FromFile, FromFileName); { Assign FromFile to FromFileName }
  AssignFile(ToFile, ToFileName);     { Assign ToFile to ToFileName }
  Reset(FromFile);                    { Open file for input }
  try
    Rewrite(ToFile);                  { Create file for output }
    try
      { copy the file an if a negative value is returned raise an exception }
      if LZCopy(TFileRec(FromFile).Handle, TFileRec(ToFile).Handle) < 0 then
        raise Exception.Create('Error using LZCopy')
    finally
      CloseFile(ToFile);  { Close ToFile }
    end;
  finally
    CloseFile(FromFile);  { Close FromFile }
  end;
end;

procedure TSetupForm.FormShow(Sender: TObject);
  var CompLib: string;
begin
  NoteBook.PageIndex := 0;

  {Get ComponentLibrary path from DELPHI.INI file; should be in the
   same directory as DELPHI.HDX}

  CompLib[0] := char(GetPrivateProfileString(
                       'Library', 'ComponentLibrary', '',
                       @CompLib[1], sizeof(CompLib)-1,
                       'DELPHI.INI'));

  {Get VCS manager from DELPHI.INI file; used to issue warning if
   a VCS is already installed }

  vcs[0]     := char(GetPrivateProfileString(
                       'Version Control', 'VCSManager', '',
                        @vcs[1], sizeof(vcs)-1,
                       'DELPHI.INI'));

  if copy(vcs, length(vcs)-11, 12) = 'EXTRAHLP.DLL' then
    vcs := '';

  BinDirectory.Text := ExtractFilePath(CompLib);
  CheckButtons;
end;

procedure TSetupForm.CheckButtons;
  var bd: string;
begin

  bd := BinDirectory.Text;
  if bd[length(bd)]<>'\' then
    bd := bd + '\';

  PrevBtn.Enabled := NoteBook.PageIndex>0;
  NextBtn.Enabled := FileExists(bd + 'DELPHI.HDX') and (noteBook.PageIndex<3);
  FinishBtn.Enabled := NoteBook.PageIndex=3;

end;

procedure TSetupForm.BrowseBinBtnClick(Sender: TObject);
  var SelectDirDlg : TSelectDirDlg;
begin
  SelectDirDlg := TSelectDirDlg.Create(self);
  try
    if SelectDirDlg.ShowModal = mrOk then
      BinDirectory.Text := SelectDirDlg.dlb.Directory;
  finally
    SelectDirDlg.Free;
    CheckButtons;
  end;
end;

procedure TSetupForm.CancelBtnClick(Sender: TObject);
begin
  close;
end;

procedure TSetupForm.NextBtnClick(Sender: TObject);
  var hdxfile: string;
begin

  if BinDirectory.Text[length(BinDirectory.Text)] <> '\' then
    BinDirectory.Text := BinDirectory.Text + '\';

  if noteBook.pageIndex=0 then
  begin
    HdxFile := BinDirectory.Text + 'DELPHI.HDX' + #0;
    WritePrivateProfileString('Jons.ExtraHelp', 'HDXFile', @HdxFile[1], 'DELPHI.INI');
  end
  else if noteBook.pageIndex = 1 then
    if vcs='' then
      noteBook.pageIndex := noteBook.pageIndex + 1; {Skip warning page}

  noteBook.pageIndex := noteBook.pageIndex + 1;
  CheckButtons;
end;

procedure TSetupForm.PrevBtnClick(Sender: TObject);
begin

  if noteBook.pageIndex = 3 then
    if vcs='' then
      noteBook.pageIndex := noteBook.pageIndex - 1; {Skip warning page}

  noteBook.pageIndex := noteBook.pageIndex - 1;
  CheckButtons;
end;

procedure TSetupForm.OptionsBtnClick(Sender: TObject);
  var OptionsDlg: TOptionsDlg;
begin
  optionsDlg := TOptionsDlg.Create(Self);
  try
    optionsDlg.HdxFile.Text := BinDirectory.Text + 'DELPHI.HDX';
    optionsDlg.ShowModal;
  finally
    optionsDlg.Free;
  end;
end;


procedure TSetupForm.FinishBtnClick(Sender: TObject);
  var source,dest: string;
      hdxfile: string;
begin

  source := ExtractFilePath(ParamStr(0))+'EXTRAHLP.DLL';
  dest := BinDirectory.Text + 'EXTRAHLP.DLL';

  if not CopyFile(source,dest) then
    showMessage('Unable to copy .DLL file!?')
  else
  begin
    dest := dest + #0;
    WritePrivateProfileString('Version Control', 'VCSManager', @dest[1], 'DELPHI.INI');
    hide;
    showMessage('ExtraHelp installation completed.');
    close;
  end;
end;

procedure TSetupForm.BinDirectoryChange(Sender: TObject);
begin
  checkButtons;
end;

end.
